pub enum TlsError<TlsErr, SvcErr> {
    Timeout,
    Tls(TlsErr),
    Service(SvcErr),
}
TLS handshake error, TLS timeout, or inner service error.

All TLS acceptors from this crate will return the SvcErr type parameter as Infallible, which can be cast to your own service type, inferred or otherwise, using into_service_error.

Variants

Timeout

TLS handshake has timed-out.

Tls(TlsErr)

Wraps TLS service errors.

Service(SvcErr)

Wraps service errors.

Implementations

Casts the infallible service error type returned from acceptors into caller’s type.

Examples
let a: TlsError<u32, Infallible> = TlsError::Tls(42);
let _b: TlsError<u32, u64> = a.into_service_error();